import os
import zipfile
import datetime
import json
import sys

# Load directory and save file name from config file
if not os.path.exists('config.json'):
    print("Unable to find config.json in local directory, exiting.")
    sys.exit(0)

config = json.load(open('config.json'))
directory = ''
file_name = 'SaveBKP'

if 'file_name' in config:
    file_name = config['file_name']
else:
    print("'file_name' attribute missing from config.json, exiting.")
    sys.exit(0)

if 'directory' in config:
    directory = config['directory']
else:
    print("'directory' attribute missing from config.json, exiting.")
    sys.exit(0)


def zipdir(path, ziph):
    abs_src = os.path.abspath(path)
    for root, dirs, files in os.walk(path):
        for file in files:
            absname = os.path.abspath(os.path.join(root, file))
            arcname = absname[len(abs_src) + 1:]
            ziph.write(absname, arcname)

def run():
    # Get date time structure
    date_now = datetime.datetime.now().strftime("%Y%m%d_%H%M%S")

    # Generate output file name
    fn = file_name + "_" + date_now + ".zip"
    
    # Create and write zip file
    zipf = zipfile.ZipFile(fn, 'w', zipfile.ZIP_DEFLATED)
    zipdir(directory, zipf)
    zipf.close()
    
    # Print result
    print("File saved as " + fn + " in local directory.")

if __name__ == '__main__':
    run()